@@ -1,28 +1,12 @@
-/*******************************************************************************
- * konsolekalendarexports.cpp                                                  *
- *                                                                             *
- * KonsoleKalendar is a command line interface to KDE calendars                *
- * Copyright (C) 2002-2004  Tuukka Pasanen <illuusio@mailcity.com>             *
- * Copyright (C) 2003-2005,2009  Allen Winter <winter@kde.org>                 *
- *                                                                             *
- * This program is free software; you can redistribute it and/or modify        *
- * it under the terms of the GNU General Public License as published by        *
- * the Free Software Foundation; either version 2 of the License, or           *
- * (at your option) any later version.                                         *
- *                                                                             *
- * This program is distributed in the hope that it will be useful,             *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of              *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the                *
- * GNU General Public License for more details.                                *
- *                                                                             *
- * You should have received a copy of the GNU General Public License           *
- * along with this program; if not, write to the Free Software                 *
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
- *                                                                             *
- * As a special exception, permission is given to link this program            *
- * with any edition of Qt, and distribute the resulting executable,            *
- * without including the source code for Qt in the source distribution.        *
- *                                                                             *
+/******************************************************************************
+ * konsolekalendarexports.cpp                                                 *
+ *                                                                            *
+ * KonsoleKalendar is a command line interface to KDE calendars               *
+ * SPDX-FileCopyrightText: 2002-2004 Tuukka Pasanen <illuusio@mailcity.com>   *
+ * SPDX-FileCopyrightText: 2003-2005 Allen Winter <winter@kde.org>            *
+ *                                                                            *
+ * SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0 *
+ *                                                                            *
  ******************************************************************************/
 /**
  * @file konsolekalendarexports.cpp
@@ -220,16 +204,15 @@ bool KonsoleKalendarExports::exportAsCSV(QTextStream *ts, const Event::Ptr &even
 
     QString delim = i18n(",");     // character to use as CSV field delimiter
     QString dquote = i18n("\"");   // character to use to quote CSV fields
-    QLocale locale;
     if (!event->allDay()) {
-        *ts <<          pF(locale.toString(date))
-            << delim << pF(locale.toString(event->dtStart().time()))
-            << delim << pF(locale.toString(date))
-            << delim << pF(locale.toString(event->dtEnd().time()));
+        *ts <<          pF(date.toString(Qt::ISODate))
+            << delim << pF(event->dtStart().time().toString(Qt::ISODate))
+            << delim << pF(date.toString(Qt::ISODate))
+            << delim << pF(event->dtEnd().time().toString(Qt::ISODate));
     } else {
-        *ts <<          pF(locale.toString(date))
+        *ts <<          pF(date.toString(Qt::ISODate))
             << delim << pF(QLatin1String(""))
-            << delim << pF(locale.toString(date))
+            << delim << pF(date.toString(Qt::ISODate))
             << delim << pF(QLatin1String(""));
     }
 
